pitchtools.Interval
===================

.. abjad-lineage:: abjad.tools.pitchtools.Interval.Interval

.. autoclass:: abjad.tools.pitchtools.Interval.Interval

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.Interval.Interval.cents
      ~abjad.tools.pitchtools.Interval.Interval.direction_number
      ~abjad.tools.pitchtools.Interval.Interval.direction_string
      ~abjad.tools.pitchtools.Interval.Interval.interval_class
      ~abjad.tools.pitchtools.Interval.Interval.is_named_interval_abbreviation
      ~abjad.tools.pitchtools.Interval.Interval.is_named_interval_quality_abbreviation
      ~abjad.tools.pitchtools.Interval.Interval.number
      ~abjad.tools.pitchtools.Interval.Interval.semitones
      ~abjad.tools.pitchtools.Interval.Interval.__abs__
      ~abjad.tools.pitchtools.Interval.Interval.__eq__
      ~abjad.tools.pitchtools.Interval.Interval.__float__
      ~abjad.tools.pitchtools.Interval.Interval.__format__
      ~abjad.tools.pitchtools.Interval.Interval.__hash__
      ~abjad.tools.pitchtools.Interval.Interval.__int__
      ~abjad.tools.pitchtools.Interval.Interval.__ne__
      ~abjad.tools.pitchtools.Interval.Interval.__neg__
      ~abjad.tools.pitchtools.Interval.Interval.__repr__
      ~abjad.tools.pitchtools.Interval.Interval.__str__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.Interval.Interval.cents
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.Interval.Interval.direction_number
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.Interval.Interval.direction_string
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.Interval.Interval.interval_class
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.Interval.Interval.number
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.Interval.Interval.semitones
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.pitchtools.Interval.Interval.is_named_interval_abbreviation
   :noindex:

.. automethod:: abjad.tools.pitchtools.Interval.Interval.is_named_interval_quality_abbreviation
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.Interval.Interval.__abs__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Interval.Interval.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Interval.Interval.__float__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Interval.Interval.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Interval.Interval.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Interval.Interval.__int__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Interval.Interval.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Interval.Interval.__neg__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Interval.Interval.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Interval.Interval.__str__
   :noindex:
